@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use experimental 'smartmatch';
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 sub import {
     my $pkg = shift;
@@ -118,7 +118,7 @@ Perinci::Import - Import functions from another module
 
 =head1 VERSION
 
-version 0.02
+This document describes version 0.03 of Perinci::Import (from Perl distribution Perinci-Import), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -198,20 +198,6 @@ subroutines using into a different name.
 
 =head1 FAQ
 
-=head1 TODO/IDEAS
-
-=over
-
-=item * Support combining tags?
-
- use Perinci::Import 'Some::Module', qw(not(:tag1));
- use Perinci::Import 'Some::Module', qw(and(:tag1,:tag2));
- use Perinci::Import 'Some::Module', qw(or(:tag1,and(:tag2,:tag3)));
-
-=item * Export non-functions (variables, etc).
-
-=back
-
 =head1 SEE ALSO
 
 L<Perinci>, L<Perinci::Exporter>
@@ -224,7 +210,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Im
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Import>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Import>.
 
 =head1 BUGS
 
@@ -236,11 +222,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
